@@ -77,7 +77,7 @@ static void setfilename(int vob)
   /* sets filenamebase to be a suitable name for a numbered video file. */
   {
     const int l=3+1+2+1+1; /* length of "vob_%02d%c_" */
-    snprintf(filenamebase + l,sizeof(filenamebase) - l, "%03d.vob", vob);
+    snprintf(filenamebase + l, sizeof(filenamebase) - l, "%03d.vob", vob);
   } /*setfilename*/
 
 static void addcst(int v, int c, int p)
@@ -105,14 +105,14 @@ static void addbutton(int v,int c, const hli_t *h)
     numvb++;
   } /*addbutton*/
 
-static int vobexists(const cell_adr_t *cells, int numcells, int vobid)
+static bool vobexists(const cell_adr_t *cells, int numcells, int vobid)
   /* do I already know about a vob with this id. */
   {
     int i;
     for (i = 0; i < numcells; i++)
         if (cells[i].vob_id == vobid)
-            return 1;
-    return 0;
+            return true;
+    return false;
   } /*vobexists*/
 
 static int getpts(int v, int c)
@@ -437,7 +437,7 @@ static void dump_buttons(xmlNodePtr cellNode, int vob)
             const struct vobbutton * const v = &vobbuttons[i];
             const hli_t * const h = &v->h;
             const xmlNodePtr buttonsNode = NewChildTag(cellNode, "buttons");
-            // XXX: add proper button overlap detection
+            // fixme: add proper button overlap detection
             if
               (
                     last
@@ -454,8 +454,8 @@ static void dump_buttons(xmlNodePtr cellNode, int vob)
                         " (cell=%d - %d).\n",
                     h->hl_gi.hli_s_ptm,
                     h->hl_gi.hli_e_ptm,
-                    getpts(v->vob,v->cell),
-                    getpts(v->vob,v->cell + 1)
+                    getpts(v->vob, v->cell),
+                    getpts(v->vob, v->cell + 1)
                   );
               } /*if*/
             AddTimeAttribute(buttonsNode, "start", h->hl_gi.hli_s_ptm, getpts(vob, 1));
@@ -520,12 +520,15 @@ static void FindWith(xmlNodePtr angleNode, const pgcit_t *pgcs, int vob, const c
     free(vobs);
   } /*FindWith*/
 
-static const char * const entries[16]={
-    "UNKNOWN0",  "UNKNOWN1",  "title",     "root",      // XXX: is 1 == fpc?
+static const char * const entries[16] =
+  /* types of entry menus in VMGM_PGCI_UT and VTSM_PGCI_UT tables. FPC doesn't
+    occur in this list because it is found via its own special pointer in the VMG IFO. */
+  {
+    "UNKNOWN0",  "UNKNOWN1",  "title",     "root",
     "subtitle",  "audio",     "angle",     "ptt",
     "UNKNOWN8",  "UNKNOWN9",  "UNKNOWN10", "UNKNOWN11",
-    "UNKNOWN12", "UNKNOWN13", "UNKNOWN14", "UNKNOWN15"
-};
+    "UNKNOWN12", "UNKNOWN13", "UNKNOWN14", "UNKNOWN15",
+  };
 
 static const char * const subp_control_modes[4]={
     "panscan","letterbox","widescreen","normal"
@@ -536,22 +539,60 @@ static void dump_pgcs(const ifo_handle_t *ifo, const pgcit_t *pgcs, const struct
   {
     if (pgcs)
       {
-        int i, j;
+        int i, j, titlenr, titletotal;
+        titlenr = 0;
+        if (titlef)
+          {
+            titletotal = 0;
+            for (i = 0; i < pgcs->nr_of_pgci_srp; i++)
+              {
+                if ((pgcs->pgci_srp[i].entry_id & 0x80) != 0)
+                  {
+                    ++titletotal;
+                  } /*if*/
+              } /*for*/
+          } /*if*/
         for (i = 0; i < pgcs->nr_of_pgci_srp; i++)
           {
             const pgc_t * const pgc = pgcs->pgci_srp[i].pgc;
             xmlNodePtr pgcNode, vobNode = 0, angleNode = 0;
             int curvob = -1;
-            AddComment
-              (
-                /*parent =*/ titleNode,
-                /*format =*/ " %s %d/%d ",
-                titlef ? "Title" : "Menu",
-                i + 1,
-                pgcs->nr_of_pgci_srp
-              );
+            if (!titlef || (pgcs->pgci_srp[i].entry_id & 0x80) != 0)
+              {
+                if (titlef)
+                  {
+                    AddComment
+                      (
+                        /*parent =*/ titleNode,
+                        /*format =*/ " Title %d/%d ",
+                        pgcs->pgci_srp[i].entry_id & 0x7f,
+                        titletotal
+                      );
+                  }
+                else
+                  {
+                    AddComment
+                      (
+                        /*parent =*/ titleNode,
+                        /*format =*/ " Menu %d/%d ",
+                        i + 1,
+                        pgcs->nr_of_pgci_srp
+                      );
+                  } /*if*/
+              } /*if*/
             pgcNode = NewChildTag(titleNode, "pgc");
-            if (!titlef && (pgcs->pgci_srp[i].entry_id & 0x80)) /* entry PGC */
+            if (titlef)
+              {
+                if ((pgcs->pgci_srp[i].entry_id & 0x80) == 0)
+                  {
+                    xmlNewProp(pgcNode, (const xmlChar *)"entry", "notitle");
+                  }
+                else
+                  {
+                    ++titlenr;
+                  } /*if*/
+              }
+            else if ((pgcs->pgci_srp[i].entry_id & 0x80) != 0) /* entry PGC */
               {
                 if (pgcs->pgci_srp[i].entry_id & 0x70)
                   {
@@ -562,7 +603,12 @@ static void dump_pgcs(const ifo_handle_t *ifo, const pgcit_t *pgcs, const struct
                         pgcs->pgci_srp[i].entry_id
                       );
                   } /*if*/
-                xmlNewProp(pgcNode, (const xmlChar *)"entry", (const xmlChar *)entries[pgcs->pgci_srp[i].entry_id&0xF]);
+                xmlNewProp
+                  (
+                    pgcNode,
+                    (const xmlChar *)"entry",
+                    (const xmlChar *)entries[pgcs->pgci_srp[i].entry_id & 0xF]
+                  );
               } /*if*/
           /* add pgc nav info */
             if (pgc->goup_pgc_nr)
@@ -786,8 +832,9 @@ static void dump_pgcs(const ifo_handle_t *ifo, const pgcit_t *pgcs, const struct
                 case CELL_PROGRAM:
                     xmlNewProp(cellNode, (const xmlChar *)"program", (const xmlChar *)"1");
                 break;
-             /* case CELL_NEITHER:
-                    do nothing */
+                case CELL_NEITHER:
+                  /* do nothing */
+                break;
                   } /*switch*/
               /* add cell still time attribute */
                 if (cp->still_time)
@@ -861,7 +908,7 @@ static void findpalette(int vob, const pgcit_t *pgcs, const uint32_t **palette,
                     p->playback_time.frame_u & 0x3f;
             if (!(*palette) || ptime > *length)
               {
-                if (*palette && memcmp(*palette,p->palette,16*sizeof(uint32_t)))
+                if (*palette && memcmp(*palette, p->palette, 16 * sizeof(uint32_t)))
                     fprintf(stderr, "WARN:  VOB %d has conflicting palettes\n", vob);
                 *palette = p->palette;
                 *length = ptime;
@@ -1048,6 +1095,11 @@ static void getVobs(dvd_reader_t *dvd, const ifo_handle_t *ifo, int titleset, in
     numcst = 0;
 
     vobs = DVDOpenFile(dvd, titleset, titlef ? DVD_READ_TITLE_VOBS : DVD_READ_MENU_VOBS);
+    if (vobs == NULL)
+      {
+      /* error message already output */
+        exit(1);
+      } /*if*/
 
     numsect = 0;
     totalsect = 0;
@@ -1168,7 +1220,7 @@ static void getVobs(dvd_reader_t *dvd, const ifo_handle_t *ifo, int titleset, in
                         bigblock[j * DVD_VIDEO_LB_LEN + 1027] == MPID_PRIVATE2 // 2nd private2
                   )
                   {
-                /* looks like a NAV pack */
+                  /* looks like a NAV pack */
                     pci_t p;
                     //dsi_t d;
                     
@@ -1267,6 +1319,11 @@ static void dump_dvd
         exit(1);
       } /*if*/
     ifo = ifoOpen(dvd, titleset);
+    if (ifo == NULL)
+      {
+      /* error message already output */
+        exit(1);
+      } /*if*/
     if (!titleset)
         numtitlesets = ifo->vmgi_mat->vmg_nr_of_title_sets;
 
