@@ -98,6 +98,7 @@
  * USA
  */
 
+#include "compat.h" /* needed for bool */
 #include "dvdvm.h"
 
 
@@ -106,7 +107,7 @@
 
 
 /* Line 189 of yacc.c  */
-#line 110 "dvdvmy.c"
+#line 111 "dvdvmy.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -214,7 +215,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 90 "dvdvmy.y"
+#line 91 "dvdvmy.y"
 
     unsigned int int_val;
     char *str_val;
@@ -223,7 +224,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 227 "dvdvmy.c"
+#line 228 "dvdvmy.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -235,7 +236,7 @@ typedef union YYSTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 239 "dvdvmy.c"
+#line 240 "dvdvmy.c"
 
 #ifdef short
 # undef short
@@ -566,16 +567,16 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   101,   101,   106,   109,   115,   118,   121,   125,   130,
-     135,   140,   144,   147,   150,   155,   158,   161,   166,   169,
-     172,   175,   178,   181,   184,   187,   190,   193,   196,   201,
-     204,   209,   216,   221,   226,   231,   236,   241,   246,   251,
-     256,   261,   266,   271,   276,   283,   286,   291,   301,   304,
-     307,   310,   313,   316,   319,   324,   327,   332,   335,   340,
-     343,   346,   349,   352,   355,   358,   361,   364,   367,   370,
-     377,   380,   383,   386,   389,   392,   395,   398,   401,   404,
-     407,   410,   417,   420,   425,   431,   434,   437,   440,   443,
-     446,   449,   452,   457,   467,   470
+       0,   102,   102,   107,   110,   116,   119,   122,   126,   131,
+     136,   141,   145,   148,   151,   156,   163,   166,   171,   178,
+     181,   184,   187,   190,   193,   196,   199,   202,   209,   214,
+     221,   226,   234,   243,   252,   257,   262,   267,   272,   277,
+     282,   287,   292,   297,   302,   309,   316,   321,   332,   335,
+     338,   341,   344,   347,   350,   355,   358,   363,   366,   371,
+     374,   377,   380,   383,   386,   389,   392,   395,   398,   401,
+     408,   411,   414,   417,   420,   423,   426,   429,   432,   435,
+     438,   441,   448,   451,   456,   462,   465,   468,   471,   474,
+     477,   480,   483,   488,   498,   501
 };
 #endif
 
@@ -1647,7 +1648,7 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 101 "dvdvmy.y"
+#line 102 "dvdvmy.y"
     {
     dvd_vm_parsed_cmd=(yyval.statement);
 ;}
@@ -1656,7 +1657,7 @@ yyreduce:
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 106 "dvdvmy.y"
+#line 107 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (1)].statement);
 ;}
@@ -1665,7 +1666,7 @@ yyreduce:
   case 4:
 
 /* Line 1455 of yacc.c  */
-#line 109 "dvdvmy.y"
+#line 110 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (2)].statement);
     (yyval.statement)->next=(yyvsp[(2) - (2)].statement);
@@ -1675,7 +1676,7 @@ yyreduce:
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 115 "dvdvmy.y"
+#line 116 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (1)].statement);
 ;}
@@ -1684,7 +1685,7 @@ yyreduce:
   case 6:
 
 /* Line 1455 of yacc.c  */
-#line 118 "dvdvmy.y"
+#line 119 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (1)].statement);
 ;}
@@ -1693,7 +1694,7 @@ yyreduce:
   case 7:
 
 /* Line 1455 of yacc.c  */
-#line 121 "dvdvmy.y"
+#line 122 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_EXIT;
@@ -1703,7 +1704,7 @@ yyreduce:
   case 8:
 
 /* Line 1455 of yacc.c  */
-#line 125 "dvdvmy.y"
+#line 126 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -1714,7 +1715,7 @@ yyreduce:
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 130 "dvdvmy.y"
+#line 131 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_GOTO;
@@ -1725,7 +1726,7 @@ yyreduce:
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 135 "dvdvmy.y"
+#line 136 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LABEL;
@@ -1736,7 +1737,7 @@ yyreduce:
   case 11:
 
 /* Line 1455 of yacc.c  */
-#line 140 "dvdvmy.y"
+#line 141 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_BREAK;
@@ -1746,7 +1747,7 @@ yyreduce:
   case 12:
 
 /* Line 1455 of yacc.c  */
-#line 144 "dvdvmy.y"
+#line 145 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (1)].statement);
 ;}
@@ -1755,7 +1756,7 @@ yyreduce:
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 147 "dvdvmy.y"
+#line 148 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(2) - (3)].statement);
 ;}
@@ -1764,7 +1765,7 @@ yyreduce:
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 150 "dvdvmy.y"
+#line 151 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (1)].statement);
 ;}
@@ -1773,8 +1774,12 @@ yyreduce:
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 155 "dvdvmy.y"
+#line 156 "dvdvmy.y"
     {
+    if ((yyvsp[(2) - (2)].int_val) < 1 || (yyvsp[(2) - (2)].int_val) > 99)
+      {
+        yyerror("titleset number out of range");
+      } /*if*/
     (yyval.int_val)=((yyvsp[(2) - (2)].int_val))+1;
 ;}
     break;
@@ -1782,7 +1787,7 @@ yyreduce:
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 158 "dvdvmy.y"
+#line 163 "dvdvmy.y"
     {
     (yyval.int_val)=1;
 ;}
@@ -1791,7 +1796,7 @@ yyreduce:
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 161 "dvdvmy.y"
+#line 166 "dvdvmy.y"
     {
     (yyval.int_val)=0;
 ;}
@@ -1800,8 +1805,12 @@ yyreduce:
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 166 "dvdvmy.y"
+#line 171 "dvdvmy.y"
     {
+    if ((yyvsp[(2) - (2)].int_val) < 1 || (yyvsp[(2) - (2)].int_val) > 99)
+      {
+        yyerror("menu number out of range");
+      } /*if*/
     (yyval.int_val)=(yyvsp[(2) - (2)].int_val);
 ;}
     break;
@@ -1809,7 +1818,7 @@ yyreduce:
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 169 "dvdvmy.y"
+#line 178 "dvdvmy.y"
     {
     (yyval.int_val)=120; // default entry
 ;}
@@ -1818,7 +1827,7 @@ yyreduce:
   case 20:
 
 /* Line 1455 of yacc.c  */
-#line 172 "dvdvmy.y"
+#line 181 "dvdvmy.y"
     {
     (yyval.int_val)=122;
 ;}
@@ -1827,7 +1836,7 @@ yyreduce:
   case 21:
 
 /* Line 1455 of yacc.c  */
-#line 175 "dvdvmy.y"
+#line 184 "dvdvmy.y"
     {
     (yyval.int_val)=123;
 ;}
@@ -1836,7 +1845,7 @@ yyreduce:
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 178 "dvdvmy.y"
+#line 187 "dvdvmy.y"
     {
     (yyval.int_val)=124;
 ;}
@@ -1845,7 +1854,7 @@ yyreduce:
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 181 "dvdvmy.y"
+#line 190 "dvdvmy.y"
     {
     (yyval.int_val)=125;
 ;}
@@ -1854,7 +1863,7 @@ yyreduce:
   case 24:
 
 /* Line 1455 of yacc.c  */
-#line 184 "dvdvmy.y"
+#line 193 "dvdvmy.y"
     {
     (yyval.int_val)=126;
 ;}
@@ -1863,7 +1872,7 @@ yyreduce:
   case 25:
 
 /* Line 1455 of yacc.c  */
-#line 187 "dvdvmy.y"
+#line 196 "dvdvmy.y"
     {
     (yyval.int_val)=127;
 ;}
@@ -1872,7 +1881,7 @@ yyreduce:
   case 26:
 
 /* Line 1455 of yacc.c  */
-#line 190 "dvdvmy.y"
+#line 199 "dvdvmy.y"
     {
     (yyval.int_val)=121;
 ;}
@@ -1881,8 +1890,12 @@ yyreduce:
   case 27:
 
 /* Line 1455 of yacc.c  */
-#line 193 "dvdvmy.y"
+#line 202 "dvdvmy.y"
     {
+    if ((yyvsp[(2) - (2)].int_val) < 1 || (yyvsp[(2) - (2)].int_val) > 99)
+      {
+        yyerror("title number out of range");
+      } /*if*/
     (yyval.int_val)=((yyvsp[(2) - (2)].int_val))|128;
 ;}
     break;
@@ -1890,7 +1903,7 @@ yyreduce:
   case 28:
 
 /* Line 1455 of yacc.c  */
-#line 196 "dvdvmy.y"
+#line 209 "dvdvmy.y"
     {
     (yyval.int_val)=0;
 ;}
@@ -1899,8 +1912,12 @@ yyreduce:
   case 29:
 
 /* Line 1455 of yacc.c  */
-#line 201 "dvdvmy.y"
+#line 214 "dvdvmy.y"
     {
+    if ((yyvsp[(2) - (2)].int_val) < 1 || (yyvsp[(2) - (2)].int_val) > 65535)
+      {
+        yyerror("chapter number out of range");
+      } /*if*/
     (yyval.int_val)=(yyvsp[(2) - (2)].int_val);
 ;}
     break;
@@ -1908,7 +1925,7 @@ yyreduce:
   case 30:
 
 /* Line 1455 of yacc.c  */
-#line 204 "dvdvmy.y"
+#line 221 "dvdvmy.y"
     {
     (yyval.int_val)=0;
 ;}
@@ -1917,10 +1934,11 @@ yyreduce:
   case 31:
 
 /* Line 1455 of yacc.c  */
-#line 209 "dvdvmy.y"
+#line 226 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_JUMP;
+  /* values already range-checked: */
     (yyval.statement)->i1=(yyvsp[(2) - (5)].int_val);
     (yyval.statement)->i2=(yyvsp[(3) - (5)].int_val);
     (yyval.statement)->i3=(yyvsp[(4) - (5)].int_val);
@@ -1930,8 +1948,12 @@ yyreduce:
   case 32:
 
 /* Line 1455 of yacc.c  */
-#line 216 "dvdvmy.y"
+#line 234 "dvdvmy.y"
     {
+    if ((yyvsp[(3) - (4)].int_val) < 1 || (yyvsp[(3) - (4)].int_val) > 65535)
+      {
+        yyerror("cell number out of range");
+      } /*if*/
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_JUMP;
     (yyval.statement)->i3=2*65536+(yyvsp[(3) - (4)].int_val);
@@ -1941,8 +1963,12 @@ yyreduce:
   case 33:
 
 /* Line 1455 of yacc.c  */
-#line 221 "dvdvmy.y"
+#line 243 "dvdvmy.y"
     {
+    if ((yyvsp[(3) - (4)].int_val) < 1 || (yyvsp[(3) - (4)].int_val) > 65535)
+      {
+        yyerror("program number out of range");
+      } /*if*/
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_JUMP;
     (yyval.statement)->i3=65536+(yyvsp[(3) - (4)].int_val);
@@ -1952,7 +1978,7 @@ yyreduce:
   case 34:
 
 /* Line 1455 of yacc.c  */
-#line 226 "dvdvmy.y"
+#line 252 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -1963,7 +1989,7 @@ yyreduce:
   case 35:
 
 /* Line 1455 of yacc.c  */
-#line 231 "dvdvmy.y"
+#line 257 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -1974,7 +2000,7 @@ yyreduce:
   case 36:
 
 /* Line 1455 of yacc.c  */
-#line 236 "dvdvmy.y"
+#line 262 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -1985,7 +2011,7 @@ yyreduce:
   case 37:
 
 /* Line 1455 of yacc.c  */
-#line 241 "dvdvmy.y"
+#line 267 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -1996,7 +2022,7 @@ yyreduce:
   case 38:
 
 /* Line 1455 of yacc.c  */
-#line 246 "dvdvmy.y"
+#line 272 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -2007,7 +2033,7 @@ yyreduce:
   case 39:
 
 /* Line 1455 of yacc.c  */
-#line 251 "dvdvmy.y"
+#line 277 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -2018,7 +2044,7 @@ yyreduce:
   case 40:
 
 /* Line 1455 of yacc.c  */
-#line 256 "dvdvmy.y"
+#line 282 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -2029,7 +2055,7 @@ yyreduce:
   case 41:
 
 /* Line 1455 of yacc.c  */
-#line 261 "dvdvmy.y"
+#line 287 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -2040,7 +2066,7 @@ yyreduce:
   case 42:
 
 /* Line 1455 of yacc.c  */
-#line 266 "dvdvmy.y"
+#line 292 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -2051,7 +2077,7 @@ yyreduce:
   case 43:
 
 /* Line 1455 of yacc.c  */
-#line 271 "dvdvmy.y"
+#line 297 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -2062,7 +2088,7 @@ yyreduce:
   case 44:
 
 /* Line 1455 of yacc.c  */
-#line 276 "dvdvmy.y"
+#line 302 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_LINK;
@@ -2073,8 +2099,12 @@ yyreduce:
   case 45:
 
 /* Line 1455 of yacc.c  */
-#line 283 "dvdvmy.y"
+#line 309 "dvdvmy.y"
     {
+    if ((yyvsp[(2) - (2)].int_val) < 1 || (yyvsp[(2) - (2)].int_val) > 65535)
+      {
+        yyerror("resume cell number out of range");
+      } /*if*/
     (yyval.int_val)=(yyvsp[(2) - (2)].int_val);
 ;}
     break;
@@ -2082,7 +2112,7 @@ yyreduce:
   case 46:
 
 /* Line 1455 of yacc.c  */
-#line 286 "dvdvmy.y"
+#line 316 "dvdvmy.y"
     {
     (yyval.int_val)=0;
 ;}
@@ -2091,10 +2121,11 @@ yyreduce:
   case 47:
 
 /* Line 1455 of yacc.c  */
-#line 291 "dvdvmy.y"
+#line 321 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_CALL;
+  /* values already range-checked: */
     (yyval.statement)->i1=(yyvsp[(2) - (6)].int_val);
     (yyval.statement)->i2=(yyvsp[(3) - (6)].int_val);
     (yyval.statement)->i3=(yyvsp[(4) - (6)].int_val);
@@ -2105,7 +2136,7 @@ yyreduce:
   case 48:
 
 /* Line 1455 of yacc.c  */
-#line 301 "dvdvmy.y"
+#line 332 "dvdvmy.y"
     {
     (yyval.int_val)=(yyvsp[(1) - (1)].int_val);
 ;}
@@ -2114,7 +2145,7 @@ yyreduce:
   case 49:
 
 /* Line 1455 of yacc.c  */
-#line 304 "dvdvmy.y"
+#line 335 "dvdvmy.y"
     {
     (yyval.int_val)=(yyvsp[(1) - (1)].int_val)+0x80;
 ;}
@@ -2123,7 +2154,7 @@ yyreduce:
   case 50:
 
 /* Line 1455 of yacc.c  */
-#line 307 "dvdvmy.y"
+#line 338 "dvdvmy.y"
     {
     (yyval.int_val)=0x81;
 ;}
@@ -2132,7 +2163,7 @@ yyreduce:
   case 51:
 
 /* Line 1455 of yacc.c  */
-#line 310 "dvdvmy.y"
+#line 341 "dvdvmy.y"
     {
     (yyval.int_val)=0x82;
 ;}
@@ -2141,7 +2172,7 @@ yyreduce:
   case 52:
 
 /* Line 1455 of yacc.c  */
-#line 313 "dvdvmy.y"
+#line 344 "dvdvmy.y"
     {
     (yyval.int_val)=0x83;
 ;}
@@ -2150,7 +2181,7 @@ yyreduce:
   case 53:
 
 /* Line 1455 of yacc.c  */
-#line 316 "dvdvmy.y"
+#line 347 "dvdvmy.y"
     {
     (yyval.int_val)=0x88;
 ;}
@@ -2159,7 +2190,7 @@ yyreduce:
   case 54:
 
 /* Line 1455 of yacc.c  */
-#line 319 "dvdvmy.y"
+#line 350 "dvdvmy.y"
     {
     (yyval.int_val)=0x80+20;
 ;}
@@ -2168,7 +2199,7 @@ yyreduce:
   case 55:
 
 /* Line 1455 of yacc.c  */
-#line 324 "dvdvmy.y"
+#line 355 "dvdvmy.y"
     {
     (yyval.int_val)=(yyvsp[(1) - (1)].int_val)-256;
 ;}
@@ -2177,7 +2208,7 @@ yyreduce:
   case 56:
 
 /* Line 1455 of yacc.c  */
-#line 327 "dvdvmy.y"
+#line 358 "dvdvmy.y"
     {
     (yyval.int_val)=(yyvsp[(1) - (1)].int_val);
 ;}
@@ -2186,7 +2217,7 @@ yyreduce:
   case 57:
 
 /* Line 1455 of yacc.c  */
-#line 332 "dvdvmy.y"
+#line 363 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(2) - (3)].statement);
 ;}
@@ -2195,7 +2226,7 @@ yyreduce:
   case 58:
 
 /* Line 1455 of yacc.c  */
-#line 335 "dvdvmy.y"
+#line 366 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_VAL;
@@ -2206,7 +2237,7 @@ yyreduce:
   case 59:
 
 /* Line 1455 of yacc.c  */
-#line 340 "dvdvmy.y"
+#line 371 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_ADD,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2215,7 +2246,7 @@ yyreduce:
   case 60:
 
 /* Line 1455 of yacc.c  */
-#line 343 "dvdvmy.y"
+#line 374 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_SUB,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2224,7 +2255,7 @@ yyreduce:
   case 61:
 
 /* Line 1455 of yacc.c  */
-#line 346 "dvdvmy.y"
+#line 377 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_MUL,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2233,7 +2264,7 @@ yyreduce:
   case 62:
 
 /* Line 1455 of yacc.c  */
-#line 349 "dvdvmy.y"
+#line 380 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_DIV,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2242,7 +2273,7 @@ yyreduce:
   case 63:
 
 /* Line 1455 of yacc.c  */
-#line 352 "dvdvmy.y"
+#line 383 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_MOD,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2251,7 +2282,7 @@ yyreduce:
   case 64:
 
 /* Line 1455 of yacc.c  */
-#line 355 "dvdvmy.y"
+#line 386 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_AND,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2260,7 +2291,7 @@ yyreduce:
   case 65:
 
 /* Line 1455 of yacc.c  */
-#line 358 "dvdvmy.y"
+#line 389 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_OR, (yyvsp[(3) - (3)].statement));
 ;}
@@ -2269,7 +2300,7 @@ yyreduce:
   case 66:
 
 /* Line 1455 of yacc.c  */
-#line 361 "dvdvmy.y"
+#line 392 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_AND,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2278,7 +2309,7 @@ yyreduce:
   case 67:
 
 /* Line 1455 of yacc.c  */
-#line 364 "dvdvmy.y"
+#line 395 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_OR, (yyvsp[(3) - (3)].statement));
 ;}
@@ -2287,7 +2318,7 @@ yyreduce:
   case 68:
 
 /* Line 1455 of yacc.c  */
-#line 367 "dvdvmy.y"
+#line 398 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_XOR,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2296,7 +2327,7 @@ yyreduce:
   case 69:
 
 /* Line 1455 of yacc.c  */
-#line 370 "dvdvmy.y"
+#line 401 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_RND;
@@ -2307,7 +2338,7 @@ yyreduce:
   case 70:
 
 /* Line 1455 of yacc.c  */
-#line 377 "dvdvmy.y"
+#line 408 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(2) - (3)].statement);
 ;}
@@ -2316,7 +2347,7 @@ yyreduce:
   case 71:
 
 /* Line 1455 of yacc.c  */
-#line 380 "dvdvmy.y"
+#line 411 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_EQ,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2325,7 +2356,7 @@ yyreduce:
   case 72:
 
 /* Line 1455 of yacc.c  */
-#line 383 "dvdvmy.y"
+#line 414 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_NE,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2334,7 +2365,7 @@ yyreduce:
   case 73:
 
 /* Line 1455 of yacc.c  */
-#line 386 "dvdvmy.y"
+#line 417 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_GTE,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2343,7 +2374,7 @@ yyreduce:
   case 74:
 
 /* Line 1455 of yacc.c  */
-#line 389 "dvdvmy.y"
+#line 420 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_GT,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2352,7 +2383,7 @@ yyreduce:
   case 75:
 
 /* Line 1455 of yacc.c  */
-#line 392 "dvdvmy.y"
+#line 423 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LTE,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2361,7 +2392,7 @@ yyreduce:
   case 76:
 
 /* Line 1455 of yacc.c  */
-#line 395 "dvdvmy.y"
+#line 426 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LT,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2370,7 +2401,7 @@ yyreduce:
   case 77:
 
 /* Line 1455 of yacc.c  */
-#line 398 "dvdvmy.y"
+#line 429 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LOR,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2379,7 +2410,7 @@ yyreduce:
   case 78:
 
 /* Line 1455 of yacc.c  */
-#line 401 "dvdvmy.y"
+#line 432 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LAND,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2388,7 +2419,7 @@ yyreduce:
   case 79:
 
 /* Line 1455 of yacc.c  */
-#line 404 "dvdvmy.y"
+#line 435 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LOR,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2397,7 +2428,7 @@ yyreduce:
   case 80:
 
 /* Line 1455 of yacc.c  */
-#line 407 "dvdvmy.y"
+#line 438 "dvdvmy.y"
     {
     (yyval.statement)=statement_expression((yyvsp[(1) - (3)].statement),VM_LAND,(yyvsp[(3) - (3)].statement));
 ;}
@@ -2406,7 +2437,7 @@ yyreduce:
   case 81:
 
 /* Line 1455 of yacc.c  */
-#line 410 "dvdvmy.y"
+#line 441 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_NOT;
@@ -2417,7 +2448,7 @@ yyreduce:
   case 82:
 
 /* Line 1455 of yacc.c  */
-#line 417 "dvdvmy.y"
+#line 448 "dvdvmy.y"
     {
     (yyval.int_val)=(yyvsp[(1) - (1)].int_val);
 ;}
@@ -2426,7 +2457,7 @@ yyreduce:
   case 83:
 
 /* Line 1455 of yacc.c  */
-#line 420 "dvdvmy.y"
+#line 451 "dvdvmy.y"
     {
     (yyval.int_val)=(yyvsp[(2) - (2)].int_val)+0x20;
 ;}
@@ -2435,7 +2466,7 @@ yyreduce:
   case 84:
 
 /* Line 1455 of yacc.c  */
-#line 425 "dvdvmy.y"
+#line 456 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_SET;
@@ -2447,7 +2478,7 @@ yyreduce:
   case 85:
 
 /* Line 1455 of yacc.c  */
-#line 431 "dvdvmy.y"
+#line 462 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_ADD,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2456,7 +2487,7 @@ yyreduce:
   case 86:
 
 /* Line 1455 of yacc.c  */
-#line 434 "dvdvmy.y"
+#line 465 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_SUB,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2465,7 +2496,7 @@ yyreduce:
   case 87:
 
 /* Line 1455 of yacc.c  */
-#line 437 "dvdvmy.y"
+#line 468 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_MUL,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2474,7 +2505,7 @@ yyreduce:
   case 88:
 
 /* Line 1455 of yacc.c  */
-#line 440 "dvdvmy.y"
+#line 471 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_DIV,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2483,7 +2514,7 @@ yyreduce:
   case 89:
 
 /* Line 1455 of yacc.c  */
-#line 443 "dvdvmy.y"
+#line 474 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_MOD,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2492,7 +2523,7 @@ yyreduce:
   case 90:
 
 /* Line 1455 of yacc.c  */
-#line 446 "dvdvmy.y"
+#line 477 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_AND,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2501,7 +2532,7 @@ yyreduce:
   case 91:
 
 /* Line 1455 of yacc.c  */
-#line 449 "dvdvmy.y"
+#line 480 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_OR,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2510,7 +2541,7 @@ yyreduce:
   case 92:
 
 /* Line 1455 of yacc.c  */
-#line 452 "dvdvmy.y"
+#line 483 "dvdvmy.y"
     {
     (yyval.statement)=statement_setop((yyvsp[(1) - (4)].int_val),VM_XOR,(yyvsp[(3) - (4)].statement));
 ;}
@@ -2519,7 +2550,7 @@ yyreduce:
   case 93:
 
 /* Line 1455 of yacc.c  */
-#line 457 "dvdvmy.y"
+#line 488 "dvdvmy.y"
     {
     (yyval.statement)=statement_new();
     (yyval.statement)->op=VM_IF;
@@ -2533,7 +2564,7 @@ yyreduce:
   case 94:
 
 /* Line 1455 of yacc.c  */
-#line 467 "dvdvmy.y"
+#line 498 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (1)].statement);
 ;}
@@ -2542,7 +2573,7 @@ yyreduce:
   case 95:
 
 /* Line 1455 of yacc.c  */
-#line 470 "dvdvmy.y"
+#line 501 "dvdvmy.y"
     {
     (yyval.statement)=(yyvsp[(1) - (3)].statement);
     (yyval.statement)->param->next->next=(yyvsp[(3) - (3)].statement);
@@ -2552,7 +2583,7 @@ yyreduce:
 
 
 /* Line 1455 of yacc.c  */
-#line 2556 "dvdvmy.c"
+#line 2587 "dvdvmy.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
