@@ -35,13 +35,17 @@
 #include <png.h>
 #endif
 
+#include "subglobals.h"
+#include "subrender.h"
 #include "subgen.h"
-#include "textsub.h"
 
 
 #define MAXX 720
 #define MAXY 576
 
+bool text_forceit = false;     /* Forcing of the subtitles */
+sub_data *textsub_subdata;
+
 static void constructblankpic(pict *p,int w,int h)
   /* allocates and fills in p with an image consisting entirely of transparent pixels */
 {
@@ -55,7 +59,7 @@ static void constructblankpic(pict *p,int w,int h)
     p->pal[0].r=0;
     p->pal[0].g=0;
     p->pal[0].b=0;
-    p->pal[0].t=0;
+    p->pal[0].a=0;
     memset(p->img,0,w*h);
 }
 
@@ -71,90 +75,102 @@ typedef struct { /* a set of colours in a subpicture or button */
 // this function scans through a picture and looks for the color that
 // the user indicated should mean transparent
 // if the color is found, it is replaced by 0,0,0,0 meaning "transparent"
-static void scanpict(stinfo *s,pict *p)
-{
+static void scanpict(stinfo *s, pict *p)
+  {
     int i;
-
     // we won't replace the background color if there is already evidence
     // of alpha channel information
-    for( i=0; i<p->numpal; i++ )
-        if( p->pal[i].t!=255 )
+    for (i = 0; i < p->numpal; i++)
+        if (p->pal[i].a != 255)
             goto skip_transreplace;
-    for( i=0; i<p->numpal; i++ )
-        if( !memcmp(p->pal+i,&s->transparentc,sizeof(palt)) ) {
-            memset(&p->pal[i],0,sizeof(palt));
+    for (i = 0; i < p->numpal; i++)
+        if (!memcmp(p->pal + i, &s->transparentc, sizeof(colorspec)))
+          { /* found matching entry */
+            memset(&p->pal[i], 0, sizeof(colorspec)); /* zap the RGB components */
             break;
-        }
-
+          } /*if; for*/
  skip_transreplace:
-    for( i=0; i<p->numpal; i++ )
-        findmasterpal(s,p->pal+i);
-}
+    for (i = 0; i < p->numpal; i++)
+        (void)findmasterpal(s, p->pal + i);
+          /* just make sure all the colours are in the colour table */
+  } /*scanpict*/
 
-static void putpixel(pict *p,int x,palt *c)
+static void putpixel(pict *p, int x, const colorspec *c)
   /* stores another pixel into pict p at offset x with colour c. Adds a new
     entry into the colour table if not already present and there's room. */
-{
+  {
     int i;
-
-    if( !c->t ) {
+    colorspec ct;
+    if (!c->a && (c->r || c->g || c->b))
+      {
       /* all transparent pixels look alike to me */
-        c->r=0;
-        c->g=0;
-        c->b=0;
-    }
-    for( i=0; i<p->numpal; i++ )
-        if( !memcmp(&p->pal[i],c,sizeof(palt)) ) {
+        ct.a = 0;
+        ct.r = 0;
+        ct.g = 0;
+        ct.b = 0;
+        c = &ct;
+      } /*if*/
+    for (i = 0; i < p->numpal; i++)
+        if (!memcmp(&p->pal[i], c, sizeof(colorspec)))
+          {
           /* matches existing palette entry */
-            p->img[x]=i;
+            p->img[x] = i;
             return;
-        }
-    if( p->numpal==256 ) {
+          } /*if; for*/
+    if (p->numpal == 256)
+      {
       /* too many colours */
-        p->img[x]=0;
+        p->img[x] = 0;
         return;
-    }
+      } /*if*/
   /* allocate new palette entry */
-    p->img[x]=p->numpal;
-/*    fprintf(stderr,"CREATING COLOR %d,%d,%d %d\n",c->r,c->g,c->b,c->t); */
-    p->pal[p->numpal++]=*c;
-}
+    p->img[x] = p->numpal;
+/*  fprintf(stderr, "CREATING COLOR %d,%d,%d %d\n", c->r, c->g, c->b, c->a); */
+    p->pal[p->numpal++] = *c;
+  } /*putpixel*/
 
-static void createimage(pict *s,int w,int h)
+static void createimage(pict *s, int w, int h)
   /* allocates memory for pixels in s with dimensions w and h. */
-{
-    s->numpal=0;
+  {
+    s->numpal = 0;
   /* ensure allocated dimensions are even */
-    s->width=w+(w&1);
-    s->height=h+(h&1);
-    s->img=malloc(s->width*s->height);
-    if( w!=s->width ) {
+    s->width = w + (w & 1);
+    s->height = h + (h & 1);
+    s->img = malloc(s->width * s->height);
+    if (w != s->width)
+      {
       /* set padding pixels along side to transparent */
         int y;
-        palt t;
-
-        t.r=0;
-        t.g=0;
-        t.b=0;
-        t.t=0;
-        for( y=0; y<h; y++ )
-            putpixel(s,w+y*s->width,&t);
-    }
-    if( h!=s->height ) {
+        colorspec t;
+        t.r = 0;
+        t.g = 0;
+        t.b = 0;
+        t.a = 0;
+        for (y = 0; y < h; y++)
+            putpixel(s, w + y * s->width, &t);
+      } /*if*/
+    if (h != s->height)
+      {
       /* set padding pixels along bottom to transparent */
         int x;
-        palt t;
-
-        t.r=0;
-        t.g=0;
-        t.b=0;
-        t.t=0;
-        for( x=0; x<s->width; x++ )
-            putpixel(s,x+h*s->width,&t);
-    }
-}
+        colorspec t;
+        t.r = 0;
+        t.g = 0;
+        t.b = 0;
+        t.a = 0;
+        for (x = 0; x < s->width; x++)
+            putpixel(s, x + h * s->width, &t);
+      } /*if*/
+  } /*createimage*/
 
 #if defined(HAVE_MAGICK) || defined(HAVE_GMAGICK)
+// meaning of A in RGBA swapped in ImageMagick 6.0.0 and GraphicsMagick 1.3.8
+#if defined(HAVE_MAGICK)
+#define XMAGICK_NEW_RGBA_MINVER 0x600
+#else // HAVE_GMAGICK
+#define XMAGICK_NEW_RGBA_MINVER 0x060300
+#define ExportImagePixels DispatchImage
+#endif
 static int read_magick(pict *s)
 /* uses ImageMagick/GraphicsMagick to read image s from s->fname. */
 {
@@ -162,6 +178,8 @@ static int read_magick(pict *s)
     ImageInfo *ii;
     ExceptionInfo ei;
     int x,y;
+    unsigned long magickver;
+    unsigned char amask;
 
     GetExceptionInfo(&ei);
     ii=CloneImageInfo(NULL);
@@ -174,40 +192,29 @@ static int read_magick(pict *s)
     }
 
     if( im->columns>MAXX || im->rows>MAXY ) {
-        fprintf(stderr,"ERR: Picture %s is too big: %lux%lu\n",s->fname,im->columns,im->rows);
+        fprintf(stderr,"ERR:  Picture %s is too big: %lux%lu\n",s->fname,im->columns,im->rows);
         DestroyImage(im);
         return -1;
     }
     createimage(s,im->columns,im->rows);
+    GetMagickVersion(&magickver);
+    amask = magickver < XMAGICK_NEW_RGBA_MINVER ? 255 : 0;
     for( y=0; y<im->rows; y++ ) {
         char pdata[MAXX*4];
 
-        if(!
-#ifdef HAVE_MAGICK
-           ExportImagePixels
-#else // HAVE_GMAGICK
-           DispatchImage
-#endif
-           (im,0,y,im->columns,1,"RGBA",CharPixel,pdata,&ei)) {
-            fprintf(stderr,"ERR: Extracting row %d from %s (%s,%s)\n",y,s->fname,ei.reason,ei.description);
+        if(!ExportImagePixels(im,0,y,im->columns,1,"RGBA",CharPixel,pdata,&ei)) {
+            fprintf(stderr,"ERR:  Extracting row %d from %s (%s,%s)\n",y,s->fname,ei.reason,ei.description);
             CatchException(&ei);
             MagickError(ei.severity,ei.reason,ei.description);
             DestroyImage(im);
             return -1;
         }
         for( x=0; x<im->columns; x++ ) {
-            palt p;
-
+            colorspec p;
             p.r=pdata[x*4];
             p.g=pdata[x*4+1];
             p.b=pdata[x*4+2];
-            // the meaning of RGBA swapped with ImageMagick 6.0.0...
-            // ...but not with GraphicsMagick
-#if defined(HAVE_MAGICK) && MagickLibVersion >= 0x600
-            p.t=pdata[x*4+3];
-#else
-            p.t=255-pdata[x*4+3];
-#endif
+            p.a = pdata[x*4+3] ^ amask;
             putpixel(s,y*s->width+x,&p);
         }
     }
@@ -226,29 +233,29 @@ static int read_png(pict *s)
     png_struct *ps;
     png_info *pi;
     png_byte **rowp;
-    unsigned long width,height;
+    png_uint_32 width,height;
     int bit_depth,color_type,channels,x,y;
 
     fp=fopen(s->fname,"rb");
     if( !fp ) {
-    fprintf(stderr,"ERR: Unable to open file %s\n",s->fname);
+    fprintf(stderr,"ERR:  Unable to open file %s\n",s->fname);
     return -1;
     }
     fread(pnghead,1,8,fp);
     if(png_sig_cmp(pnghead,0,8)) {
-    fprintf(stderr,"ERR: File %s isn't a png\n",s->fname);
+    fprintf(stderr,"ERR:  File %s isn't a png\n",s->fname);
     fclose(fp);
     return -1;
     }
     ps=png_create_read_struct(PNG_LIBPNG_VER_STRING,NULL,NULL,NULL);
     if( !ps ) {
-        fprintf(stderr,"ERR: Initializing png\n");
+        fprintf(stderr,"ERR:  Initializing png\n");
         fclose(fp);
         return -1;
     }
     pi=png_create_info_struct(ps);
     if( !pi ) {
-        fprintf(stderr,"ERR: Initializing png\n");
+        fprintf(stderr,"ERR:  Initializing png\n");
         png_destroy_read_struct(&ps,NULL,NULL);
         fclose(fp);
         return -1;
@@ -271,7 +278,7 @@ static int read_png(pict *s)
     assert(bit_depth==8); // 8bpp, not 1, 2, 4, or 16
     assert(!(color_type&PNG_COLOR_MASK_PALETTE)); // not a palette
     if( width>MAXX || height>MAXY ) {
-        fprintf(stderr,"ERR: PNG %s is too big: %lux%lu\n",s->fname,width,height);
+        fprintf(stderr,"ERR:  PNG %s is too big: %lux%lu\n",s->fname,width,height);
         png_destroy_read_struct(&ps,&pi,NULL);
         return -1;
     }
@@ -279,8 +286,7 @@ static int read_png(pict *s)
     for( y=0; y<height; y++ ) {
         unsigned char *d=rowp[y];
         for( x=0; x<width; x++ ) {
-            palt p;
-
+            colorspec p;
             if(color_type&PNG_COLOR_MASK_COLOR) {
                 p.r=*d++;
                 p.g=*d++;
@@ -291,9 +297,9 @@ static int read_png(pict *s)
                 p.b=p.r;
             }
             if( color_type&PNG_COLOR_MASK_ALPHA )
-                p.t=*d++;
+                p.a=*d++;
             else
-                p.t=255;
+                p.a=255;
             d+=channels;
             putpixel(s,y*s->width+x,&p);
         }
@@ -309,64 +315,61 @@ static int read_png(pict *s)
 
 static int read_frame(pict *s)
   /* fills in s from textsub_image_buffer. */
-{
-  int x,y;
-
-  createimage(s,movie_width,movie_height);
-  for( y=0; y<movie_height; y++ )
   {
-    unsigned char *d=textsub_image_buffer+(y*movie_width*3);
+    int x, y;
+    createimage(s, movie_width, movie_height);
+    for (y = 0; y < movie_height; y++)
+      {
+          const unsigned char * d = textsub_image_buffer + y * movie_width * 4;
+          for (x = 0; x < movie_width; x++)
+            {
+              colorspec p;
+              p.r = *d++;
+              p.g = *d++;
+              p.b = *d++;
+              p.a = *d++;
+              putpixel(s, y * s->width + x, &p);
+            } /*for*/
+      } /*for*/
+    return 0;
+  } /*read_frame*/
 
-    for( x=0; x<movie_width; x++ )
-    {
-      palt p;
-      p.r=*d++;
-      p.g=*d++;
-      p.b=*d++;
-      p.t=255;
-      putpixel(s,y*s->width+x,&p);
-    }
-  }
-  return 0;
-}
-
-static int read_pic(stinfo *s,pict *p)
-{
-    int r=0;
-    if ( have_textsub)
-    {
-        textsub_render(s->sub_title);
-        s->forced = s->sub_title->text_forced;
-        r=read_frame(p);
-    }
-    else
-    {
-        if( !p->fname )
+static int read_pic(stinfo *s, pict *p)
+  /* gets the image(s) specified by p into s. */
+  {
+    int r = 0;
+    if (have_textsub)
+      {
+        vo_update_osd(s->sub_title); /* will allocate and render into textsub_image_buffer */
+        s->forced = text_forceit;
+        r = read_frame(p);
+      }
+    else /* read image file */
+      {
+        if (!p->fname)
             return 0;
 #if defined(HAVE_MAGICK) || defined(HAVE_GMAGICK)
-        r=read_magick(p);
+        r = read_magick(p);
 #else
-        r=read_png(p);
+        r = read_png(p);
 #endif
-    }
-    if( !r )
-        scanpict(s,p);
+      } /*if*/
+    if (!r)
+        scanpict(s, p);
     return r;
-}
+  } /*read_pic*/
 
-
-static int checkcolor(palgroup *p,int c)
+static bool checkcolor(palgroup *p,int c)
   /* tries to put colour c into palette p, returning true iff successful or already there. */
 {
     int i;
-
     for( i=0; i<p->numpal; i++ )
         if( p->pal[i]==c )
-            return 1;
+            return true;
     if( p->numpal==4 )
-        return 0;
+        return false;
     p->pal[p->numpal++]=c;
-    return 1;
+    return true;
 }
 
 static int gettricolor(stinfo *s,int p,int useimg)
@@ -381,7 +384,7 @@ static int gettricolor(stinfo *s,int p,int useimg)
             s->sel.img[p];
   } /*gettricolor*/
 
-static int pickbuttongroups(stinfo *s, int ng, int useimg)
+static bool pickbuttongroups(stinfo *s, int ng, int useimg)
   /* tries to assign the buttons in s to ng unique groups. useimg indicates
     whether to look at the pixels in s->img in addition to s->hlt and s->sel. */
   {
@@ -431,7 +434,7 @@ static int pickbuttongroups(stinfo *s, int ng, int useimg)
                 fprintf
                   (
                     stderr,
-                    "ERR: Button coordinates out of range: (%d,%d)-(%d,%d)\n",
+                    "ERR:  Button coordinates out of range: (%d,%d)-(%d,%d)\n",
                     b->r.x0, b->r.y0, b->r.x1, b->r.y1
                   );
             exit(1);
@@ -540,11 +543,11 @@ ui_found:
                   (
                         tri == -1
                     ||
-                            s->img.pal[(tri >> 16) & 0xFF].t == 0
+                            s->img.pal[(tri >> 16) & 0xFF].a == 0
                         &&
-                            s->hlt.pal[(tri >> 8) & 0xFF].t == 0
+                            s->hlt.pal[(tri >> 8) & 0xFF].a == 0
                         &&
-                            s->sel.pal[tri & 0xFF].t == 0
+                            s->sel.pal[tri & 0xFF].a == 0
                   )
                   {
                     spare = k;
@@ -558,19 +561,19 @@ ui_found:
               /* got an unused slot, make up a transparent entry to exchange it with */
                 tri = 0;
                 for (k = 0; k < s->img.numpal; ++k)
-                    if (s->img.pal[k].t == 0)
+                    if (s->img.pal[k].a == 0)
                       {
                         tri |= k << 16;
                         break;
                       } /*if; for*/
                 for (k = 0; k < s->hlt.numpal; ++k)
-                    if (s->hlt.pal[k].t == 0)
+                    if (s->hlt.pal[k].a == 0)
                       {
                         tri |= k << 8;
                         break;
                       } /*if; for*/
                 for (k = 0; k < s->sel.numpal; ++k)
-                    if (s->sel.pal[k].t == 0)
+                    if (s->sel.pal[k].a == 0)
                       {
                         tri |= k;
                         break;
@@ -586,7 +589,7 @@ ui_found:
 
         fprintf(stderr, "INFO: Pickbuttongroups, success with %d groups, useimg=%d\n", ng, useimg);
         s->numgroups = ng;
-        return 1;
+        return true;
 trynext:
         continue; // 'deprecated use of label at end of compound statement'
       } /*for i*/
@@ -594,7 +597,7 @@ trynext:
 impossible:
     free(bpgs);
     free(gs);
-    return 0;
+    return false;
   } /*pickbuttongroups*/
 
 static void fixnames(stinfo *s)
@@ -639,10 +642,10 @@ static void brphelp(int a0, int a1, int b0, int b1, int d, int *angle, int *dist
     *dist = sqrt(d1 * d1+d * d);
   } /*brphelp*/
 
-static int buttonrelpos(const rectangle *a, const rectangle *b, int *angle, int *dist)
+static bool buttonrelpos(const rectangle *a, const rectangle *b, int *angle, int *dist)
   /* computes an angle and distance from the position of rectangle a to that of rectangle b,
-    if I can figure one out. Returns 1 if the case is sufficiently simple for me to handle,
-    0 otherwise. */
+    if I can figure one out. Returns true if the case is sufficiently simple for me to handle,
+    false otherwise. */
   {
     // from b to a
     if (a->y1 <= b->y0)
@@ -650,7 +653,7 @@ static int buttonrelpos(const rectangle *a, const rectangle *b, int *angle, int
       /* a lies above b with no vertical overlap */
         brphelp(a->x0, a->x1, b->x0, b->x1, b->y0 - a->y1, angle, dist);
         // fprintf(stderr,"from %dx%d-%dx%d to %dx%d-%dx%d is angle %d, dist %d\n",b->x0,b->y0,b->x1,b->y1,a->x0,a->y0,a->x1,a->y1,*angle,*dist);
-        return 1;
+        return true;
       } /*if*/
     if (a->y0 >= b->y1)
       {
@@ -658,7 +661,7 @@ static int buttonrelpos(const rectangle *a, const rectangle *b, int *angle, int
         brphelp(a->x0, a->x1, b->x0, b->x1, a->y0 - b->y1, angle, dist);
         *angle = 180 - *angle;
         // fprintf(stderr,"from %dx%d-%dx%d to %dx%d-%dx%d is angle %d, dist %d\n",b->x0,b->y0,b->x1,b->y1,a->x0,a->y0,a->x1,a->y1,*angle,*dist);
-        return 1;
+        return true;
       } /*if*/
     if (a->x1 <= b->x0)
       {
@@ -666,7 +669,7 @@ static int buttonrelpos(const rectangle *a, const rectangle *b, int *angle, int
         brphelp(a->y0, a->y1, b->y0, b->y1, b->x0 - a->x1, angle, dist);
         *angle = 270 - *angle;
         // fprintf(stderr,"from %dx%d-%dx%d to %dx%d-%dx%d is angle %d, dist %d\n",b->x0,b->y0,b->x1,b->y1,a->x0,a->y0,a->x1,a->y1,*angle,*dist);
-        return 1;
+        return true;
       } /*if*/
     if (a->x0 >= b->x1)
       {
@@ -674,11 +677,11 @@ static int buttonrelpos(const rectangle *a, const rectangle *b, int *angle, int
         brphelp(a->y0, a->y1, b->y0, b->y1, a->x0 - b->x1, angle, dist);
         *angle = 90 + *angle;
         // fprintf(stderr,"from %dx%d-%dx%d to %dx%d-%dx%d is angle %d, dist %d\n",b->x0,b->y0,b->x1,b->y1,a->x0,a->y0,a->x1,a->y1,*angle,*dist);
-        return 1;
+        return true;
       } /*if*/
   /* none of the above */
     // fprintf(stderr,"from %dx%d-%dx%d to %dx%d-%dx%d -- no easy comparison\n",b->x0,b->y0,b->x1,b->y1,a->x0,a->y0,a->x1,a->y1);
-    return 0;
+    return false;
   } /*buttonrelpos*/
 
 static void findbestbindir(stinfo *s, const button *b, char **dest, int a)
@@ -731,34 +734,34 @@ static void detectdirections(stinfo *s)
 #define MAX(a,b) (((a)>(b))?(a):(b))
 #define MIN(a,b) (((a)<(b))?(a):(b))
 
-static int scanvline(stinfo *s,unsigned char *v,rectangle *r,int x,int d)
+static bool scanvline(stinfo *s,unsigned char *v,rectangle *r,int x,int d)
 {
     int i,j;
 
     for( j=1; j<=s->outlinewidth; j++ ) {
         x+=d;
         if( x<0 || x>=s->xd )
-            return 0;
+            return false;
         for( i=MAX(r->y0-j,0); i<MIN(r->y1+j,s->yd); i++ )
             if( v[i*s->xd+x] )
-                return 1;
+                return true;
     }
-    return 0;
+    return false;
 }
 
-static int scanhline(stinfo *s,unsigned char *v,rectangle *r,int y,int d)
+static bool scanhline(stinfo *s,unsigned char *v,rectangle *r,int y,int d)
 {
     int i,j;
 
     for( j=1; j<=s->outlinewidth; j++ ) {
         y+=d;
         if( y<0 || y>=s->yd )
-            return 0;
+            return false;
         for( i=MAX(r->x0-j,0); i<MIN(r->x1+j,s->xd); i++ )
             if( v[y*s->xd+i] )
-                return 1;
+                return true;
     }
-    return 0;
+    return false;
 }
 
 static void detectbuttons(stinfo *s)
@@ -772,12 +775,12 @@ static void detectbuttons(stinfo *s)
     if( !s->outlinewidth )
         s->outlinewidth=1;
     for( i=0; i<s->xd*s->yd; i++ )
-        visitmask[i]=( s->hlt.pal[s->hlt.img[i]].t || s->sel.pal[s->sel.img[i]].t ) ? 1 : 0;
+        visitmask[i]=( s->hlt.pal[s->hlt.img[i]].a || s->sel.pal[s->sel.img[i]].a ) ? 1 : 0;
     for( y=0; y<s->yd; y++ )
         for( x=0; x<s->xd; x++ )
             if( visitmask[y*s->xd+x] ) {
                 rectangle r;
-                int didwork;
+                bool didwork;
 
                 r.x0=x;
                 r.y0=y;
@@ -785,22 +788,22 @@ static void detectbuttons(stinfo *s)
                 r.y1=y+1;
 
                 do {
-                    didwork=0;
+                    didwork = false;
                     while( scanvline(s,visitmask,&r,r.x0,-1) ) {
                         r.x0--;
-                        didwork=1;
+                        didwork = true;
                     }
                     while( scanvline(s,visitmask,&r,r.x1-1,1) ) {
                         r.x1++;
-                        didwork=1;
+                        didwork = true;
                     }
                     while( scanhline(s,visitmask,&r,r.y0,-1) ) {
                         r.y0--;
-                        didwork=1;
+                        didwork = true;
                     }
                     while( scanhline(s,visitmask,&r,r.y1-1,1) ) {
                         r.y1++;
-                        didwork=1;
+                        didwork = true;
                     }
                 } while(didwork);
 
@@ -859,7 +862,7 @@ static void detectbuttons(stinfo *s)
     }
 }
 
-static int imgfix(stinfo *s)
+static bool imgfix(stinfo *s)
   /* fills in the subpicture/button details. */
 {
     int i, useimg, w, h, x, y, x0, y0;
@@ -897,8 +900,8 @@ static int imgfix(stinfo *s)
         assert(useimg); // at this point I don't want to deal with blocking the primary subtitle image
         if (useimg < 0)
           {
-            fprintf(stderr, "ERR: Cannot pick button masks\n");
-            return 0;
+            fprintf(stderr, "ERR:  Cannot pick button masks\n");
+            return false;
           } /*if*/
 
         for (i = 0; i < s->numbuttons; i++)
@@ -919,14 +922,14 @@ static int imgfix(stinfo *s)
                           } /*if; for*/
                     if (dc == -1)
                       { /* shouldn't occur */
-                        fprintf(stderr, "ERR: Button %d cannot find color %06x in group %d\n",
+                        fprintf(stderr, "ERR:  Button %d cannot find color %06x in group %d\n",
                             i, c, b->grp - 1);
                         assert(dc != -1); /* instant assertion failure */
                       } /*if*/
                     if (s->fimg[p] != dc && s->fimg[p] != 255)
                       { /* pixel already occupied by another button */
-                        fprintf(stderr, "ERR: Overlapping buttons\n");
-                        return 0;
+                        fprintf(stderr, "ERR:  Overlapping buttons\n");
+                        return false;
                       } /*if*/
                     s->fimg[p] = dc;
                   } /*for; for*/
@@ -937,7 +940,7 @@ static int imgfix(stinfo *s)
         s->pal[i].r = 255;
         s->pal[i].g = 255;
         s->pal[i].b = 255;
-        s->pal[i].t = 0;
+        s->pal[i].a = 0;
       } /*for*/
     for (i = 0; i < w * h; i++)
         if (s->fimg[i] != 255)
@@ -947,20 +950,20 @@ static int imgfix(stinfo *s)
         if (s->fimg[i] == 255)
           { /* haven't already done this pixel */
             int j;
-            const palt * const p = &s->img.pal[s->img.img[i]];
+            const colorspec * const p = &s->img.pal[s->img.img[i]];
             for (j = 0; j < 4; j++)
               /* see if colour is already in s->pal */
-                if (!memcmp(&s->pal[j], p, sizeof(palt)))
+                if (!memcmp(&s->pal[j], p, sizeof(colorspec)))
                     goto if_found;
             for (j = 0; j < 4; j++) /* insert new colour in place of unused/transparent entry */
-                if (s->pal[j].t == 0 && s->pal[j].r == 255) /* not checking all the components? */
+                if (s->pal[j].a == 0 && s->pal[j].r == 255) /* not checking all the components? */
                   {
                     s->pal[j] = *p;
                     goto if_found;
                   } /*if*/
           /* no room in s->pal */
-            fprintf(stderr, "ERR: Too many colors in base picture\n");
-            return 0;
+            fprintf(stderr, "ERR:  Too many colors in base picture\n");
+            return false;
 if_found:
             s->fimg[i] = j;
           } /*if; for*/
@@ -976,11 +979,11 @@ if_found:
           {
             if
               (
-                    s->img.pal[s->img.img[i]].t
+                    s->img.pal[s->img.img[i]].a
                 ||
-                    s->hlt.pal[s->hlt.img[i]].t
+                    s->hlt.pal[s->hlt.img[i]].a
                 ||
-                    s->sel.pal[s->sel.img[i]].t
+                    s->sel.pal[s->sel.img[i]].a
               )
               {
                 if (y0 == -1)
@@ -997,7 +1000,7 @@ if_found:
       { // empty image?
         s->xd = w;
         s->yd = h;
-        return 1;
+        return true;
       } /*if*/
     x0 &= -2;
     y0 &= -2;
@@ -1015,20 +1018,20 @@ if_found:
       } /*for*/
     s->x0 += x0;
     s->y0 += y0;
-    return 1;
+    return true;
   } /*imgfix*/
 
-int process_subtitle(stinfo *s)
+bool process_subtitle(stinfo *s)
   /* loads the specified image files and builds the subpicture in memory. */
 {
     int w=0,h=0;
     int iline=0;
 
-    if( !s ) return 0;
+    if( !s ) return false;
     if( read_pic(s,&s->img) ) {
         if(debug > -1)
             fprintf(stderr, "WARN: Bad image,  skipping line %d\n", iline - 1);
-        return 0;
+        return false;
     }
     if( s->img.img && !w ) {
         w=s->img.width;
@@ -1037,7 +1040,7 @@ int process_subtitle(stinfo *s)
     if( read_pic(s,&s->hlt) ) {
         if(debug > -1)
             fprintf(stderr, "WARN: Bad image,  skipping line %d\n", iline - 1);
-        return 0;
+        return false;
     }
     if( s->hlt.img && !w ) {
         w=s->hlt.width;
@@ -1046,7 +1049,7 @@ int process_subtitle(stinfo *s)
     if( read_pic(s,&s->sel) ) {
         if(debug > -1)
             fprintf(stderr, "WARN: Bad image,  skipping line %d\n", iline - 1);
-        return 0;
+        return false;
     }
     if( s->sel.img && !w ) {
         w=s->sel.width;
@@ -1055,7 +1058,7 @@ int process_subtitle(stinfo *s)
 
     if( !w ) {
         fprintf(stderr,"WARN: No picture, skipping line %d\n",iline-1);
-        return 0;
+        return false;
     }
   /* check consistent dimensions, fill in missing images with blanks */
     if( !s->img.img ) {
@@ -1063,33 +1066,33 @@ int process_subtitle(stinfo *s)
         fprintf(stderr,"INFO: Constructing blank img\n");
     } else if( s->img.width!=w || s->img.height!=h ) {
         fprintf(stderr,"WARN: Inconsistent picture widths, skipping line %d\n",iline-1);
-        return 0;
+        return false;
     }
     if( !s->hlt.img ) {
         constructblankpic(&s->hlt,w,h);
         fprintf(stderr,"INFO: Constructing blank hlt\n");
     } else if( s->hlt.width!=w || s->hlt.height!=h ) {
         fprintf(stderr,"WARN: Inconsistent picture widths, skipping line %d\n",iline-1);
-        return 0;
+        return false;
     }
     if( !s->sel.img ) {
         constructblankpic(&s->sel,w,h);
         fprintf(stderr,"INFO: Constructing blank sel\n");
     } else if( s->sel.width!=w || s->sel.height!=h ) {
         fprintf(stderr,"WARN: Inconsistent picture widths, skipping line %d\n",iline-1);
-        return 0;
+        return false;
     }
 
     if( !imgfix(s) ) /* data in img to fimg */
     {
         if (debug > -1)
         {
-            fprintf(stderr, "ERR: Blank image, skipping line %d\n", iline - 1);
+            fprintf(stderr, "ERR:  Blank image, skipping line %d\n", iline - 1);
         }
-        return 0;
+        return false;
     }
 
-    return 1;
+    return true;
 }
 
 void image_init()
